@@ -1,11 +1,10 @@
 #[cfg(test)]
 mod conn_map_test;
 
-use super::error::*;
+use crate::error::*;
 use crate::vnet::conn::UdpConn;
 use crate::Conn;
 
-use anyhow::Result;
 use std::collections::HashMap;
 use std::net::SocketAddr;
 use std::sync::Arc;
@@ -31,13 +30,13 @@ impl UdpConnMap {
         let mut port_map = self.port_map.lock().await;
         if let Some(conns) = port_map.get(&addr.port()) {
             if addr.ip().is_unspecified() {
-                return Err(Error::ErrAddressAlreadyInUse.into());
+                return Err(Error::ErrAddressAlreadyInUse);
             }
 
             for c in conns {
                 let laddr = c.local_addr().await?;
                 if laddr.ip().is_unspecified() || laddr.ip() == addr.ip() {
-                    return Err(Error::ErrAddressAlreadyInUse.into());
+                    return Err(Error::ErrAddressAlreadyInUse);
                 }
             }
         }
@@ -87,7 +86,7 @@ impl UdpConnMap {
                     let laddr = c.local_addr().await?;
                     if laddr.ip().is_unspecified() {
                         // This can't happen!
-                        return Err(Error::ErrCannotRemoveUnspecifiedIp.into());
+                        return Err(Error::ErrCannotRemoveUnspecifiedIp);
                     }
 
                     if laddr.ip() == addr.ip() {
@@ -97,7 +96,7 @@ impl UdpConnMap {
                 }
             }
         } else {
-            return Err(Error::ErrNoSuchUdpConn.into());
+            return Err(Error::ErrNoSuchUdpConn);
         }
 
         if new_conns.is_empty() {
