@@ -1,5 +1,4 @@
-use super::error::*;
-use anyhow::Result;
+use crate::error::*;
 use ipnet::*;
 use std::net::SocketAddr;
 use std::str::FromStr;
@@ -49,7 +48,7 @@ impl Interface {
                     }
                     prefix
                 }
-                _ => return Err(Error::ErrInvalidMask.into()),
+                _ => return Err(Error::ErrInvalidMask),
             }
         } else {
             32
