@@ -1,11 +1,10 @@
 #[cfg(test)]
 mod nat_test;
 
-use super::error::*;
+use crate::error::*;
 use crate::vnet::chunk::Chunk;
 use crate::vnet::net::UDP_STR;
 
-use anyhow::Result;
 use std::collections::{HashMap, HashSet};
 use std::net::IpAddr;
 use std::ops::Add;
@@ -122,10 +121,10 @@ impl NetworkAddressTranslator {
             nat_type.mapping_life_time = Duration::from_secs(0);
 
             if config.mapped_ips.is_empty() {
-                return Err(Error::ErrNatRequriesMapping.into());
+                return Err(Error::ErrNatRequriesMapping);
             }
             if config.mapped_ips.len() != config.local_ips.len() {
-                return Err(Error::ErrMismatchLengthIp.into());
+                return Err(Error::ErrMismatchLengthIp);
             }
         } else {
             // Normal (NAPT) behavior
@@ -243,7 +242,7 @@ impl NetworkAddressTranslator {
                             )),
                         }
                     } else {
-                        return Err(Error::ErrNatRequriesMapping.into());
+                        return Err(Error::ErrNatRequriesMapping);
                     };
 
                     {
@@ -292,7 +291,7 @@ impl NetworkAddressTranslator {
             return Ok(Some(to));
         }
 
-        Err(Error::ErrNonUdpTranslationNotSupported.into())
+        Err(Error::ErrNonUdpTranslationNotSupported)
     }
 
     pub(crate) async fn translate_inbound(
@@ -309,12 +308,11 @@ impl NetworkAddressTranslator {
                     let dst_port = from.destination_addr().port();
                     to.set_destination_addr(&format!("{}:{}", dst_ip, dst_port))?;
                 } else {
-                    return Err(Error::new(format!(
+                    return Err(Error::Other(format!(
                         "drop {} as {:?}",
                         from,
                         Error::ErrNoAssociatedLocalAddress
-                    ))
-                    .into());
+                    )));
                 }
             } else {
                 // Normal (NAPT) behavior
@@ -333,13 +331,12 @@ impl NetworkAddressTranslator {
                     {
                         let filters = m.filters.lock().await;
                         if !filters.contains(&filter_key) {
-                            return Err(Error::new(format!(
+                            return Err(Error::Other(format!(
                                 "drop {} as the remote {} {:?}",
                                 from,
                                 filter_key,
                                 Error::ErrHasNoPermission
-                            ))
-                            .into());
+                            )));
                         }
                     }
 
@@ -353,12 +350,11 @@ impl NetworkAddressTranslator {
 
                     to.set_destination_addr(&m.local)?;
                 } else {
-                    return Err(Error::new(format!(
+                    return Err(Error::Other(format!(
                         "drop {} as {:?}",
                         from,
                         Error::ErrNoNatBindingFound
-                    ))
-                    .into());
+                    )));
                 }
             }
 
@@ -372,7 +368,7 @@ impl NetworkAddressTranslator {
             return Ok(Some(to));
         }
 
-        Err(Error::ErrNonUdpTranslationNotSupported.into())
+        Err(Error::ErrNonUdpTranslationNotSupported)
     }
 
     // caller must hold the mutex
