@@ -628,7 +628,7 @@ async fn test_net_virtual_loopback2() -> Result<()> {
     Ok(())
 }
 
-async fn get_ipaddr(nic: &Arc<Mutex<dyn Nic + Send + Sync>>) -> Result<IpAddr, Error> {
+async fn get_ipaddr(nic: &Arc<Mutex<dyn Nic + Send + Sync>>) -> Result<IpAddr> {
     let n = nic.lock().await;
     let eth0 = n
         .get_interface("eth0")
